/* A silly little calculator implemented in Object Rexx using
   Java components for the UI. 2001-05-02, 2003-01-23, ---rgf, 2003-05-10
   - 2010-05-24, rgf: changed code to use pure Rexx event handlers
   ("bsf\samples\bsh\calculator.js" served as an example)

   license:

    ------------------------ Apache Version 2.0 license -------------------------
       Copyright (C) 2001-2010 Rony G. Flatscher

       Licensed under the Apache License, Version 2.0 (the "License");
       you may not use this file except in compliance with the License.
       You may obtain a copy of the License at

           http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing, software
       distributed under the License is distributed on an "AS IS" BASIS,
       WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
       See the License for the specific language governing permissions and
       limitations under the License.
    -----------------------------------------------------------------------------
*/

if      BsfInvokedBy()=1 then say "This Rexx program was invoked by Java!"
else if BsfInvokedBy()=2 then say "This Rexx program was invoked by Rexx, JVM loaded by Rexx!"
else                          say "No JVM present, we got troubles ..."

.bsf~bsf.import("java.awt.TextField", "awtTextField")
.bsf~bsf.import("java.awt.Label"    , "awtLabel"    )

   -- Create a directory which can be passed on to Rexx event handlers
userData=.directory~new

   -- Create a Java RexxProxy for controlling the closing of the application
rexxCloseEH =.RexxCloseAppEventHandler~new   -- Rexx event handler
   -- Create Java RexxProxy for the Rexx event handler
rpCloseEH=BsfCreateRexxProxy(rexxCloseEH, , "java.awt.event.WindowListener" )

f = .bsf~new("java.awt.Frame", "BSH Calculator (ooRexx)")
f~addWindowListener(rpCloseEH)   -- assign RexxProxy for Rexx event handler

rpMathEH=BsfCreateRexxProxy(.RexxDoMathEH~new, userData, "java.awt.event.ActionListener", -
                                                         "java.awt.event.FocusListener")

f1 = .awtTextField~new("", 20)
f1~addActionListener(rpMathEH)
f1~addFocusListener(rpMathEH)
userData~f1=f1                   -- make Java object accessible from Rexx handler

f2 = .awtTextField~new("", 20)
f2~addActionListener(rpMathEH)
f2~addFocusListener(rpMathEH)
userData~f2=f2                   -- make Java object accessible from Rexx handler

p = .bsf~new( "java.awt.Panel") ~~setLayout(.bsf~new("java.awt.GridLayout", 2, 2))
p ~~add(.awtLabel~new("Enter operand")) ~~add(f1)
p ~~add(.awtLabel~new("Enter operand")) ~~add(f2)

f ~~add("North", p) ~~add("Center", .awtLabel~new("Results:"))

p =  .bsf~new("java.awt.Panel") ~~setLayout(.bsf~new("java.awt.GridLayout", 4, 2))

sum = .awtTextField~new("", 20) ~~setEditable(.false) ~~setFocusable(.false)
userData~sum=sum                 -- make Java object accessible from Rexx handler
p ~~add(.awtLabel~new("Sum")) ~~add(sum)

diff = .awtTextField~new("", 20) ~~setEditable(.false) ~~setFocusable(.false)
userData~diff=diff               -- make Java object accessible from Rexx handler
p ~~add(.awtLabel~new("Difference")) ~~add(diff)

prod = .awtTextField~new("", 20) ~~setEditable(.false) ~~setFocusable(.false)
userData~prod=prod               -- make Java object accessible from Rexx handler
p ~~add(.awtLabel~new("Product")) ~~add(prod)

quo = .awtTextField~new("", 20) ~~setEditable(.false) ~~setFocusable(.false)
userData~quo=quo                 -- make Java object accessible from Rexx handler
p ~~add(.awtLabel~new("Quotient")) ~~add(quo)

f ~~add("South", p) ~~pack ~~show ~~toFront

rexxCloseEH~waitForExit -- wait until we are allowed to end the program
call SysSleep .2        -- let Java's RexxProxy finalizations find a running Rexx instance

::requires BSF.CLS    -- get Java support


/* ------------------------------------------------------------------------ */
/* Rexx event handler to set "close app" indicator */
::class RexxCloseAppEventHandler
::method init        /* constructor */
  expose closeApp
  closeApp  = .false   -- if set to .true, then it is safe to close the app

::attribute closeApp          -- indicates whether app should be closed

::method unknown              -- intercept unhandled events, do nothing

::method windowClosing        -- event method (from WindowListener)
  expose closeApp
  closeApp=.true              -- indicate that the app should close

::method waitForExit          -- method blocks until attribute is set to .true
  expose closeApp
  guard on when closeApp=.true


/* ------------------------------------------------------------------------ */
/* Rexx event handler to set "close app" indicator */
::class RexxDoMathEH
::method unknown              -- intercept uninteresting events

::method actionPerformed      -- event method (from WindowListener)
  use arg eventObject, slotDir

  userData=slotDir~userData   -- get userData directory
   n1 = getField(userData~f1); if n1="-" then n1=-1;else if n1="+" then n1=1
   n2 = getField(userData~f2); if n2="-" then n2=-1;else if n2="+" then n2=1
   userData~sum ~setText(n1+n2)
   userData~diff~setText(n1-n2)
   userData~prod~setText(n1*n2)
   if n2=0 then userData~quo~setText("DIVISION by 0 !!!")
           else userData~quo~setText(n1/n2)
   return

getField: procedure
   use arg f
   t=f~getText
   if t="" then return 0
   return t


::method focusLost            -- event method (from WindowListener)
  forward message (actionPerformed) -- let method "actionPerformed" do the work

